<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="gl_ES">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>hai unsí</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1 mensaxe nova</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 minutos hoxe</translation>
    </message>
</context>
</TS>